==================
Welcome to Covasim
==================

Covasim is a stochastic agent-based simulator, written in Python, for exploring and analyzing the COVID-19 epidemic. 

**There's a lot here, where should I start?** 

- Take a quick look at the overview, which provides a general introduction. 
- When you're ready to sink your teeth in, the tutorials will help you get started using Covasim.
- If you're looking for a specific feature or keyword, you should be able to find it with the search feature (top left).
- Still have questions? Send us an email at info@covasim.org. We're happy to help!

Full contents
=============

.. toctree::
   :maxdepth: 4

   overview
   tutorials
   papers
   faq
   whatsnew
   parameters
   data
   glossary
   conduct
   contributing
   style
   modules